@@ -1,5 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
+ * Copyright © 2014 Pranav Kant
  * Copyright © 2012, 2013, 2014 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
@@ -50,6 +51,7 @@
 #include "photos-search-provider.h"
 #include "photos-single-item-job.h"
 #include "photos-source-manager.h"
+#include "photos-tracker-extract-priority.h"
 
 
 struct _PhotosApplicationPrivate
@@ -75,6 +77,7 @@ struct _PhotosApplicationPrivate
   PhotosModeController *mode_cntrlr;
   PhotosSearchContextState *state;
   PhotosSearchProvider *search_provider;
+  TrackerExtractPriority *extract_priority;
   guint32 activation_timestamp;
 };
 
@@ -125,6 +128,15 @@ photos_application_refresh_data_free (PhotosApplicationRefreshData *data)
   g_slice_free (PhotosApplicationRefreshData, data);
 }
 
+static void
+photos_application_help (PhotosApplication *self, GVariant *parameter)
+{
+  GtkWindow *parent;
+
+  parent = gtk_application_get_active_window (GTK_APPLICATION (self));
+  gtk_show_uri (gtk_window_get_screen (parent), "help:gnome-photos",
+                GDK_CURRENT_TIME, NULL);
+}
 
 static void
 photos_application_about (PhotosApplication *self, GVariant *parameter)
@@ -543,6 +555,72 @@ photos_application_stop_miners (PhotosApplication *self)
 }
 
 
+static void
+photos_application_tracker_clear_rdf_types (GObject *source_object, GAsyncResult *res, gpointer user_data)
+{
+  PhotosApplication *self = PHOTOS_APPLICATION (user_data);
+  GError *error;
+
+  error = NULL;
+  if (!tracker_extract_priority_call_clear_rdf_types_finish (self->priv->extract_priority, res, &error))
+    {
+      g_warning ("Unable to call ClearRdfTypes: %s", error->message);
+      g_error_free (error);
+      goto out;
+    }
+
+ out:
+  g_object_unref (self);
+}
+
+
+static void
+photos_application_tracker_set_rdf_types (GObject *source_object, GAsyncResult *res, gpointer user_data)
+{
+  PhotosApplication *self = PHOTOS_APPLICATION (user_data);
+  GError *error;
+
+  error = NULL;
+  if (!tracker_extract_priority_call_set_rdf_types_finish (self->priv->extract_priority, res, &error))
+    {
+      g_warning ("Unable to call SetRdfTypes: %s", error->message);
+      g_error_free (error);
+      goto out;
+    }
+
+ out:
+  g_object_unref (self);
+}
+
+
+static void
+photos_application_tracker_extract_priority (GObject *source_object, GAsyncResult *res, gpointer user_data)
+{
+  PhotosApplication *self = PHOTOS_APPLICATION (user_data);
+  PhotosApplicationPrivate *priv = self->priv;
+  GError *error;
+  const gchar *const rdf_types[] = {"nfo:Image", NULL};
+
+  error = NULL;
+  priv->extract_priority = tracker_extract_priority_proxy_new_for_bus_finish (res, &error);
+  if (error != NULL)
+    {
+      g_warning ("Unable to create TrackerExtractPriority proxy: %s", error->message);
+      g_error_free (error);
+      goto out;
+    }
+
+  tracker_extract_priority_call_set_rdf_types (priv->extract_priority,
+                                               rdf_types,
+                                               NULL,
+                                               photos_application_tracker_set_rdf_types,
+                                               g_object_ref (self));
+
+ out:
+  g_object_unref (self);
+}
+
+
 static void
 photos_application_window_mode_changed (PhotosApplication *self, PhotosWindowMode mode, PhotosWindowMode old_mode)
 {
@@ -626,6 +704,20 @@ photos_application_dbus_unregister (GApplication *application,
 }
 
 
+static void
+photos_application_shutdown (GApplication *application)
+{
+  PhotosApplication *self = PHOTOS_APPLICATION (application);
+
+  tracker_extract_priority_call_clear_rdf_types (self->priv->extract_priority,
+                                                 NULL,
+                                                 photos_application_tracker_clear_rdf_types,
+                                                 g_object_ref (self));
+
+  G_APPLICATION_CLASS (photos_application_parent_class)->shutdown (application);
+}
+
+
 static void
 photos_application_startup (GApplication *application)
 {
@@ -673,6 +765,14 @@ photos_application_startup (GApplication *application)
                                                          NULL,
                                                          NULL);
 
+  tracker_extract_priority_proxy_new_for_bus (G_BUS_TYPE_SESSION,
+                                              G_DBUS_PROXY_FLAGS_NONE,
+                                              "org.freedesktop.Tracker1.Miner.Extract",
+                                              "/org/freedesktop/Tracker1/Extract/Priority",
+                                              NULL,
+                                              photos_application_tracker_extract_priority,
+                                              g_object_ref (self));
+
   priv->item_mngr = photos_item_manager_dup_singleton ();
 
   /* A dummy reference to keep it alive during the lifetime of the
@@ -683,6 +783,7 @@ photos_application_startup (GApplication *application)
   priv->mode_cntrlr = photos_mode_controller_dup_singleton ();
 
   action = g_simple_action_new ("about", NULL);
+
   g_signal_connect_swapped (action, "activate", G_CALLBACK (photos_application_about), self);
   g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (action));
   g_object_unref (action);
@@ -744,6 +845,11 @@ photos_application_startup (GApplication *application)
 
   photos_application_init_app_menu (self);
 
+  action = g_simple_action_new ("help", NULL);
+  g_signal_connect_swapped (action, "activate", G_CALLBACK (photos_application_help), self);
+  g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (action));
+  g_object_unref (action);
+
   gtk_application_add_accelerator (GTK_APPLICATION (self), "<Primary>q", "app.quit", NULL);
   gtk_application_add_accelerator (GTK_APPLICATION (self), "F11", "app.fullscreen", NULL);
   gtk_application_add_accelerator (GTK_APPLICATION (self), "F10", "app.gear-menu", NULL);
@@ -800,6 +906,7 @@ photos_application_dispose (GObject *object)
   g_clear_object (&priv->camera_cache);
   g_clear_object (&priv->mode_cntrlr);
   g_clear_object (&priv->search_provider);
+  g_clear_object (&priv->extract_priority);
 
   if (priv->state != NULL)
     {
@@ -847,6 +954,7 @@ photos_application_class_init (PhotosApplicationClass *class)
   application_class->activate = photos_application_activate;
   application_class->dbus_register = photos_application_dbus_register;
   application_class->dbus_unregister = photos_application_dbus_unregister;
+  application_class->shutdown = photos_application_shutdown;
   application_class->startup = photos_application_startup;
 
   /* TODO: Add miners-changed signal */
@@ -868,3 +976,20 @@ photos_application_new (void)
                        "flags", G_APPLICATION_IS_SERVICE,
                        NULL);
 }
+
+
+gint
+photos_application_get_scale_factor (PhotosApplication *self)
+{
+  GList *windows;
+  gint scale_factor;
+
+  /* We do not use priv->main_window to allow widgets to use this
+   * method while they are being constructed. The widget hierarchy is
+   * created in PhotosMainWindow:constructed and at that point
+   * priv->main_window is NULL.
+   */
+  windows = gtk_application_get_windows (GTK_APPLICATION (self));
+  scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (windows->data));
+  return scale_factor;
+}
