@@ -27,12 +27,14 @@
 
 #include <string.h>
 
+#include <gdk/gdk.h>
 #include <gio/gio.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <libgd/gd.h>
 #include <tracker-sparql.h>
 
+#include "photos-application.h"
 #include "photos-base-item.h"
 #include "photos-collection-icon-watcher.h"
 #include "photos-delete-item-job.h"
@@ -48,8 +50,8 @@
 
 struct _PhotosBaseItemPrivate
 {
-  GdkPixbuf *icon;
-  GdkPixbuf *pristine_icon;
+  cairo_surface_t *surface;
+  GdkPixbuf *original_icon;
   GeglNode *graph;
   GeglNode *node;
   GeglRectangle bbox;
@@ -133,12 +135,19 @@ static void
 photos_base_item_check_effects_and_update_info (PhotosBaseItem *self)
 {
   PhotosBaseItemPrivate *priv = self->priv;
+  GApplication *app;
   GIcon *pix;
   GList *emblem_icons = NULL;
-  GdkPixbuf *icon;
+  GList *windows;
+  GdkPixbuf *emblemed_pixbuf = NULL;
+  GdkPixbuf *thumbnailed_pixbuf = NULL;
+  GdkWindow *window;
+  gint scale;
 
-  icon = g_object_ref (priv->icon);
-  priv->pristine_icon = g_object_ref (icon);
+  if (priv->original_icon == NULL)
+    goto out;
+
+  emblemed_pixbuf = g_object_ref (priv->original_icon);
 
   if (priv->favorite)
     {
@@ -157,7 +166,7 @@ photos_base_item_check_effects_and_update_info (PhotosBaseItem *self)
       gint width;
 
       emblem_icons = g_list_reverse (emblem_icons);
-      emblemed_icon = g_emblemed_icon_new (G_ICON (priv->icon), NULL);
+      emblemed_icon = g_emblemed_icon_new (G_ICON (priv->original_icon), NULL);
       for (l = emblem_icons; l != NULL; l = g_list_next (l))
         {
           GEmblem *emblem;
@@ -170,8 +179,8 @@ photos_base_item_check_effects_and_update_info (PhotosBaseItem *self)
 
       theme = gtk_icon_theme_get_default ();
 
-      width = gdk_pixbuf_get_width (priv->icon);
-      height = gdk_pixbuf_get_height (priv->icon);
+      width = gdk_pixbuf_get_width (priv->original_icon);
+      height = gdk_pixbuf_get_height (priv->original_icon);
       size = (width > height) ? width : height;
 
       icon_info = gtk_icon_theme_lookup_by_gicon (theme, emblemed_icon, size, GTK_ICON_LOOKUP_FORCE_SIZE);
@@ -189,37 +198,62 @@ photos_base_item_check_effects_and_update_info (PhotosBaseItem *self)
             }
           else
             {
-              g_object_unref (icon);
-              icon = tmp;
+              g_object_unref (emblemed_pixbuf);
+              emblemed_pixbuf = tmp;
             }
 
           g_object_unref (icon_info);
         }
+
+      g_object_unref (emblemed_icon);
     }
 
-  g_object_unref (priv->icon);
+  g_clear_pointer (&priv->surface, (GDestroyNotify) cairo_surface_destroy);
 
   if (priv->thumb_path != NULL)
     {
       GtkBorder *slice;
 
       slice = photos_utils_get_thumbnail_frame_border ();
-      priv->icon = gd_embed_image_in_frame (icon,
-                                            "resource:///org/gnome/photos/thumbnail-frame.png",
-                                            slice,
-                                            slice);
+      thumbnailed_pixbuf = gd_embed_image_in_frame (emblemed_pixbuf,
+                                                    "resource:///org/gnome/photos/thumbnail-frame.png",
+                                                    slice,
+                                                    slice);
       gtk_border_free (slice);
     }
   else
-    priv->icon = g_object_ref (icon);
+    thumbnailed_pixbuf = g_object_ref (emblemed_pixbuf);
+
+  app = g_application_get_default ();
+  scale = photos_application_get_scale_factor (PHOTOS_APPLICATION (app));
+  windows = gtk_application_get_windows (GTK_APPLICATION (app));
+  window = gtk_widget_get_window (GTK_WIDGET (windows->data));
+  priv->surface = gdk_cairo_surface_create_from_pixbuf (thumbnailed_pixbuf, scale, window);
 
   g_signal_emit (self, signals[INFO_UPDATED], 0);
 
-  g_object_unref (icon);
+ out:
+  g_clear_object (&thumbnailed_pixbuf);
+  g_clear_object (&emblemed_pixbuf);
   g_list_free_full (emblem_icons, g_object_unref);
 }
 
 
+static void
+photos_base_item_set_original_icon (PhotosBaseItem *self, GdkPixbuf *icon)
+{
+  PhotosBaseItemPrivate *priv = self->priv;
+
+  if (icon != NULL)
+    {
+      g_clear_object (&priv->original_icon);
+      priv->original_icon = g_object_ref (icon);
+    }
+
+  photos_base_item_check_effects_and_update_info (self);
+}
+
+
 static void
 photos_base_item_create_thumbnail_in_thread_func (gpointer data, gpointer user_data)
 {
@@ -354,14 +388,10 @@ photos_base_item_get_id (PhotosFilterable *filterable)
 static void
 photos_base_item_icon_updated (PhotosBaseItem *self, GIcon *icon)
 {
-  PhotosBaseItemPrivate *priv = self->priv;
-
   if (icon == NULL)
     return;
 
-  g_clear_object (&priv->icon);
-  priv->icon = g_object_ref (icon);
-  photos_base_item_check_effects_and_update_info (self);
+  photos_base_item_set_original_icon (self, GDK_PIXBUF (icon));
 }
 
 
@@ -400,10 +430,11 @@ photos_base_item_refresh_thumb_path_pixbuf (GObject *source_object, GAsyncResult
 {
   PhotosBaseItem *self = PHOTOS_BASE_ITEM (user_data);
   PhotosBaseItemPrivate *priv = self->priv;
+  GdkPixbuf *pixbuf = NULL;
   GError *error = NULL;
   GInputStream *stream = G_INPUT_STREAM (source_object);
 
-  priv->icon = gdk_pixbuf_new_from_stream_finish (res, &error);
+  pixbuf = gdk_pixbuf_new_from_stream_finish (res, &error);
   if (error != NULL)
     {
       GFile *file;
@@ -420,10 +451,11 @@ photos_base_item_refresh_thumb_path_pixbuf (GObject *source_object, GAsyncResult
       goto out;
     }
 
-  photos_base_item_check_effects_and_update_info (self);
+  photos_base_item_set_original_icon (self, pixbuf);
 
  out:
   g_input_stream_close_async (stream, G_PRIORITY_DEFAULT, NULL, NULL, NULL);
+  g_clear_object (&pixbuf);
   g_object_unref (self);
 }
 
@@ -636,6 +668,8 @@ static void
 photos_base_item_update_icon_from_type (PhotosBaseItem *self)
 {
   PhotosBaseItemPrivate *priv = self->priv;
+  GdkPixbuf *pixbuf = NULL;
+  GError *error;
   GIcon *icon = NULL;
   GtkIconInfo *info = NULL;
   GtkIconTheme *theme;
@@ -649,18 +683,27 @@ photos_base_item_update_icon_from_type (PhotosBaseItem *self)
 
   theme = gtk_icon_theme_get_default ();
   icon_size = photos_utils_get_icon_size ();
+
   info = gtk_icon_theme_lookup_by_gicon (theme,
                                          icon,
                                          icon_size,
                                          GTK_ICON_LOOKUP_FORCE_SIZE | GTK_ICON_LOOKUP_GENERIC_FALLBACK);
-  if (info != NULL)
+  if (info == NULL)
+    goto out;
+
+  error = NULL;
+  pixbuf = gtk_icon_info_load_icon (info, &error);
+  if (error != NULL)
     {
-      priv->icon = gtk_icon_info_load_icon (info, NULL);
-      /* TODO: use a GError */
+      g_warning ("Unable to load pixbuf: %s", error->message);
+      g_error_free (error);
+      goto out;
     }
 
-  photos_base_item_check_effects_and_update_info (self);
+  photos_base_item_set_original_icon (self, pixbuf);
 
+ out:
+  g_clear_object (&pixbuf);
   g_clear_object (&info);
   g_clear_object (&icon);
 }
@@ -837,9 +880,9 @@ photos_base_item_dispose (GObject *object)
   PhotosBaseItem *self = PHOTOS_BASE_ITEM (object);
   PhotosBaseItemPrivate *priv = self->priv;
 
+  g_clear_pointer (&priv->surface, (GDestroyNotify) cairo_surface_destroy);
   g_clear_object (&priv->graph);
-  g_clear_object (&priv->icon);
-  g_clear_object (&priv->pristine_icon);
+  g_clear_object (&priv->original_icon);
   g_clear_object (&priv->watcher);
   g_clear_object (&priv->sel_cntrlr);
   g_clear_object (&priv->cursor);
@@ -1115,13 +1158,6 @@ photos_base_item_get_height (PhotosBaseItem *self)
 }
 
 
-GdkPixbuf *
-photos_base_item_get_icon (PhotosBaseItem *self)
-{
-  return self->priv->icon;
-}
-
-
 const gchar *
 photos_base_item_get_identifier (PhotosBaseItem *self)
 {
@@ -1158,9 +1194,9 @@ photos_base_item_get_name (PhotosBaseItem *self)
 
 
 GdkPixbuf *
-photos_base_item_get_pristine_icon (PhotosBaseItem *self)
+photos_base_item_get_original_icon (PhotosBaseItem *self)
 {
-  return self->priv->pristine_icon;
+  return self->priv->original_icon;
 }
 
 
@@ -1178,6 +1214,13 @@ photos_base_item_get_source_name (PhotosBaseItem *self)
 }
 
 
+cairo_surface_t *
+photos_base_item_get_surface (PhotosBaseItem *self)
+{
+  return self->priv->surface;
+}
+
+
 const gchar *
 photos_base_item_get_type_description (PhotosBaseItem *self)
 {
