@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012, 2013 Red Hat, Inc.
+ * Copyright © 2012, 2013, 2014 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -117,8 +117,6 @@ gdouble             photos_base_item_get_focal_length   (PhotosBaseItem *self);
 
 gint64              photos_base_item_get_height         (PhotosBaseItem *self);
 
-GdkPixbuf          *photos_base_item_get_icon           (PhotosBaseItem *self);
-
 const gchar        *photos_base_item_get_identifier     (PhotosBaseItem *self);
 
 gdouble             photos_base_item_get_iso_speed      (PhotosBaseItem *self);
@@ -129,12 +127,14 @@ gint64              photos_base_item_get_mtime          (PhotosBaseItem *self);
 
 const gchar        *photos_base_item_get_name           (PhotosBaseItem *self);
 
-GdkPixbuf          *photos_base_item_get_pristine_icon  (PhotosBaseItem *self);
+GdkPixbuf          *photos_base_item_get_original_icon  (PhotosBaseItem *self);
 
 const gchar        *photos_base_item_get_resource_urn   (PhotosBaseItem *self);
 
 const gchar        *photos_base_item_get_source_name    (PhotosBaseItem *self);
 
+cairo_surface_t    *photos_base_item_get_surface        (PhotosBaseItem *self);
+
 const gchar        *photos_base_item_get_type_description (PhotosBaseItem *self);
 
 const gchar        *photos_base_item_get_uri            (PhotosBaseItem *self);
