@@ -80,11 +80,12 @@ photos_collection_icon_watcher_create_collection_icon (PhotosCollectionIconWatch
 
   for (l = priv->items; l != NULL; l = l->next)
     {
-      GdkPixbuf *pristine_icon;
+      GdkPixbuf *original_icon;
       PhotosBaseItem *item = PHOTOS_BASE_ITEM (l->data);
 
-      pristine_icon = photos_base_item_get_pristine_icon (item);
-      icons = g_list_prepend (icons, g_object_ref (pristine_icon));
+      original_icon = photos_base_item_get_original_icon (item);
+      if (original_icon != NULL)
+        icons = g_list_prepend (icons, g_object_ref (original_icon));
     }
   icons = g_list_reverse (icons);
 
