@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2013 Red Hat, Inc.
+ * Copyright © 2013, 2014 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,12 +25,14 @@
 
 #include "config.h"
 
+#include <gio/gio.h>
 #include <glib.h>
 #include <tracker-sparql.h>
 
 #include "photos-create-collection-job.h"
 #include "photos-query.h"
 #include "photos-query-builder.h"
+#include "photos-search-context.h"
 #include "photos-tracker-queue.h"
 
 
@@ -193,7 +195,9 @@ photos_create_collection_job_run (PhotosCreateCollectionJob *self,
                                   gpointer user_data)
 {
   PhotosCreateCollectionJobPrivate *priv = self->priv;
+  GApplication *app;
   PhotosQuery *query;
+  PhotosSearchContextState *state;
 
   if (G_UNLIKELY (priv->queue == NULL))
     {
@@ -205,7 +209,10 @@ photos_create_collection_job_run (PhotosCreateCollectionJob *self,
   priv->callback = callback;
   priv->user_data = user_data;
 
-  query = photos_query_builder_create_collection_query (priv->name);
+  app = g_application_get_default ();
+  state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
+
+  query = photos_query_builder_create_collection_query (state, priv->name);
   photos_tracker_queue_update_blank (priv->queue,
                                      query->sparql,
                                      NULL,
