@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012, 2013 Red Hat, Inc.
+ * Copyright © 2012, 2013, 2014 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,6 +27,8 @@
 
 #include <gtk/gtk.h>
 
+#include "photos-main-toolbar.h"
+
 G_BEGIN_DECLS
 
 #define PHOTOS_TYPE_EMBED (photos_embed_get_type ())
@@ -70,6 +72,8 @@ GType                  photos_embed_get_type               (void) G_GNUC_CONST;
 
 GtkWidget             *photos_embed_new                    (void);
 
+PhotosMainToolbar     *photos_embed_get_main_toolbar       (PhotosEmbed *self);
+
 G_END_DECLS
 
 #endif /* PHOTOS_EMBED_H */
